"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cheerio = require("cheerio");
const page_type_1 = require("./page-type");
const util_1 = require("./util");
const sessionParser = (function () {
    return {
        pageType: page_type_1.default.session,
        parse: function (html) {
            const $ = cheerio.load(html);
            const id = parseSessionId($);
            const quotaType = parseNodeValue($, "Bandwidth Quota Schedule:");
            let _total = parseNodeValue($, "Group Allowed Bandwidth:");
            if (!_total || _total === "-") {
                _total = "3.00 GB";
            }
            const total = util_1.parseToMb(_total);
            let _upload = parseNodeValue($, "Upload:");
            if (!_upload || _upload === "-") {
                _upload = "0 MB";
            }
            const upload = util_1.parseToMb(_upload);
            let _download = parseNodeValue($, "Download:");
            if (!_download || _download === "-") {
                _download = "0 MB";
            }
            const download = util_1.parseToMb(_download);
            let _used = parseNodeValue($, "Total Bandwidth:");
            if (!_used || _used === "-") {
                _used = "0 MB";
            }
            const used = util_1.parseToMb(_used);
            return { id, quotaType, total, upload, download, used };
        }
    };
    function parseNodeValue($, key) {
        /* Todo: re-write this block, it's a tad messy */
        const values = Array.from($("td.para1"))
            .map(function (node) {
            return node.children[0];
        })
            .filter(function (node) {
            const sanitize = function (value) {
                value.toLocaleLowerCase().trim();
            };
            return node && node.data ? sanitize(key) === sanitize(node.data) : false;
        })
            .map(function (node) {
            let currentNode = node.parent;
            /* keep moving until we hit an adjacent sibling */
            do {
                currentNode = currentNode.next;
            } while (currentNode.type != "tag");
            return currentNode.children[0].data;
        });
        return values.length > 0 ? values[0] : null;
    }
    function parseSessionId($) {
        const content = $("meta").last()[0].attribs.content;
        return Number.parseInt(content.slice(content.lastIndexOf("=") + 1));
    }
})();
const parsers = [sessionParser];
class PageParser {
    static getParser(pageType) {
        return parsers.find(parser => parser.pageType === pageType);
    }
}
exports.default = PageParser;
