"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const page_type_1 = require("./page-type");
function createMatcher(pageType, regex) {
    return {
        pageType: pageType,
        isMatch: function (html) {
            return regex.test(html);
        }
    };
}
const pageMatchers = [
    createMatcher(page_type_1.default.session, /\WTime Remaining\W/i),
    createMatcher(page_type_1.default.authenticationFailed, /\WAuthentication Failed\W/i),
    createMatcher(page_type_1.default.invalidRequest, /\WInvalid Request\W/i),
    createMatcher(page_type_1.default.confirmOverride, /\Walready logged\W/i),
    createMatcher(page_type_1.default.loggedOut, /\WYou have been successfully Logged Out!!!\W/i),
    createMatcher(page_type_1.default.maxSessionsReached, /\WThe no of UserSense session of User:\W/i)
];
class PageTypeResolver {
    /**
     * Resolves static html to a PageType instance.
     */
    static resolveType(pageContent) {
        if (!pageContent) {
            throw new Error("page must be valid html markup");
        }
        const pageMatcher = pageMatchers.find(resolver => resolver.isMatch(pageContent));
        if (pageMatcher) {
            return pageMatcher.pageType;
        }
        else {
            return page_type_1.default.unknown;
        }
    }
}
exports.default = PageTypeResolver;
