"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
function syncSetInterval(callback, interval, delay) {
    let clearRequested;
    const update = () => __awaiter(this, void 0, void 0, function* () {
        if (clearRequested) {
            return;
        }
        yield callback();
        setTimeout(update, interval);
    });
    setTimeout(update, delay || 0);
    return {
        clear: () => (clearRequested = true)
    };
}
exports.syncSetInterval = syncSetInterval;
function parseToMb(value) {
    let { magnitude, type } = parseMagnitudeAndType(value);
    if (type === "kb") {
        magnitude = magnitude / 1024;
    }
    else if (type == "gb") {
        magnitude = magnitude * 1024;
    }
    return magnitude;
}
exports.parseToMb = parseToMb;
function parseToGb(value) {
    let { magnitude, type } = parseMagnitudeAndType(value);
    if (type === "mb") {
        magnitude = magnitude / 1024;
    }
    else if (type === "kb") {
        magnitude = magnitude / (1024 * 1024);
    }
    return magnitude;
}
exports.parseToGb = parseToGb;
function parseMagnitudeAndType(value) {
    // convert to lowercase and remove all whitespaces to make parsing easy
    value = value.toLocaleLowerCase();
    value = value.replace(/\s/g, '');
    const type = ["kb", "mb", "gb"].find(t => value.includes(t));
    if (!type) {
        throw new Error("unknown or invalid data type encountered");
    }
    /* since, all values have two character suffixes like mb, gb, kb etc. we can
    /* easily parse the value by stripping off the last two characters */
    const magnitude = Number.parseFloat(value.substr(0, value.length - 2));
    return { type, magnitude };
}
exports.parseMagnitudeAndType = parseMagnitudeAndType;
